
<p align="center">
  <a href="https://github.com/memory-formation/psychos">
    <picture>
        <source media="(prefers-color-scheme: dark)" srcset="https://github.com/memory-formation/psychos/raw/main/docs/assets/psychos-dark.svg">
        <img alt="psychos" src="https://github.com/memory-formation/psychos/raw/main/docs/assets/psychos.svg">
    </picture>
  </a>
</p>

[![PyPI version](https://badge.fury.io/py/psychos.svg)](https://pypi.org/project/psychos/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/psychos)
[![Documentation Status](https://readthedocs.org/projects/psychos/badge/?version=latest)](https://psychos.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/memory-formation/psychos/graph/badge.svg?token=BFLLUMRKR0)](https://codecov.io/gh/memory-formation/psychos)
[![Run Tests](https://github.com/memory-formation/psychos/actions/workflows/tests.yml/badge.svg)](https://github.com/memory-formation/psychos/actions/workflows/tests.yml)
[![Based on](https://img.shields.io/badge/based%20on-Pyglet-orange.svg)](https://pyglet.org/)
[![Project Status: WIP – Initial development is in progress, but there has not yet been a stable, usable release suitable for the public.](https://www.repostatus.org/badges/latest/wip.svg)](https://www.repostatus.org/#wip)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](https://github.com/memory-formation/psychos/blob/main/LICENSE)
![Platform](https://img.shields.io/badge/platform-Windows%20|%20OS%20X%20|%20Linux-blue.svg)

**Psychos** is a modern, lightweight Python library for creating precise, timing-sensitive behavioral experiments—designed for cognitive neuroscience and related fields. 
Built for ease of use, the library simplifies the coding process, allowing researchers to create experiments with clear and readable code.


## Installation

You can install **Psychos** with pip:

```bash
pip install psychos
```

## Documentation

For full documentation, visit [Read the Docs](https://psychos.readthedocs.io/en/latest/).

## Issues

If you encounter any issues or have suggestions for improvements, please [open an issue](https://github.com/memory-formation/psychos/issues) on GitHub. We greatly value your feedback and contributions to make **Psychos** better!

## Contributing

Psychos is maintained by [DMF Group](https://brainvitge.org/groups/memory_formation/) at the [University of Barcelona](https://web.ub.edu/en/web/ub/). If you would like to contribute, please open an issue or submit a pull request on GitHub. We welcome contributions from the community!

## License

Psychos is licensed under the MIT License. See the [LICENSE](LICENSE) file for more details.

